@@ -3,7 +3,6 @@ import numpy as np
 from matplotlib import pyplot as plt
 from .analysis_report import AnalysisReport
 
-
 def monotonicity_mse(predictions):
     """Monotonicity Mean Square Error
 
@@ -80,7 +79,7 @@ def check_monotonicity_single_sample(model, sample, feature, start, stop, step=1
         'monotonic' : bool
              If the list of values is monotonic.
 
-        'monotonic_score': float
+        'monotonic_mse': float
             MSE between the list of values and it`s closest monotonic aproximation. 
 
     graphs : List
@@ -112,11 +111,11 @@ def check_monotonicity_single_sample(model, sample, feature, start, stop, step=1
     report.graphs.append(fig)
     if monotonic:
         report.metrics["monotonic"] = True
-        report.metrics["monotonic_score"] = 1
+        report.metrics["monotonic_mse"] = 0
     else:
         report.metrics["monotonic"] = False
         monotonic_curve, m_mse_score = monotonicity_mse(predictions)
-        report.metrics["monotonic_score"] = m_mse_score
+        report.metrics["monotonic_mse"] = m_mse_score
         plt.plot(colValues, monotonic_curve, linestyle='dashed', color='red', alpha=0.7, label="Monotonic Approximation")
     plt.plot(colValues, predictions, color='blue', alpha=0.7, label="Predictions Curve")
     plt.title(f"Model: {type(model).__name__}")
@@ -125,8 +124,7 @@ def check_monotonicity_single_sample(model, sample, feature, start, stop, step=1
     plt.legend(loc="lower right")
     return report
 
-
-def check_monotonicity_multiple_samples(model, sample, feature, start, stop, step=1):
+def check_monotonicity_multiple_samples(model, samples, feature, start, stop, step=1):
     '''Monotonicity Analysis for multiple examples
 
     Parameters
@@ -134,8 +132,8 @@ def check_monotonicity_multiple_samples(model, sample, feature, start, stop, ste
     model : sklearn model or str
         Model that will be used to make predictions. Could be a model object or a path to a model file.
 
-    sample : pandas.DataFrame
-        Pandas DataFrame containing one row that will be used as base point.
+    samples : pandas.DataFrame
+        Pandas DataFrame containing two or more rows that will be used as base point.
 
     feature : str
         Name of the feature being analysed.
@@ -172,7 +170,7 @@ def check_monotonicity_multiple_samples(model, sample, feature, start, stop, ste
         'monotonic' : bool
              If the list of values is monotonic.
 
-        'monotonic_score': float
+        'monotonic_mse': float
             MSE between the list of values and it`s closest monotonic aproximation. 
         
         'monotonic_means_std': float
@@ -181,8 +179,8 @@ def check_monotonicity_multiple_samples(model, sample, feature, start, stop, ste
     graphs : List
             List of all the figures created.
     '''
-    if len(sample) < 2:
-        raise Exception("Sample must have multiple examples, please use 'check_monotonicity_single_sample' for single example")
+    if len(samples) < 2:
+        raise Exception("Samples must have multiple examples, please use 'check_monotonicity_single_sample' for single example")
     if type(model) == str:
         with open(model, 'rb') as f:
             model = pickle.load(f)
@@ -191,11 +189,10 @@ def check_monotonicity_multiple_samples(model, sample, feature, start, stop, ste
     colValues = []
     predictions = []
 
-
     for i in np.arange(start,stop,step):
         colValues.append(i)
-        sample[feature] = i
-        prediction = model.predict_proba(sample)
+        samples[feature] = i
+        prediction = model.predict_proba(samples)
         predictions.append(np.mean(prediction[0][1]))
 
     monotonic =  (all(predictions[i] <= predictions[i + 1] for i in range(len(predictions) - 1)) or all(predictions[i] >= predictions[i + 1] for i in range(len(predictions) - 1)))
@@ -206,11 +203,11 @@ def check_monotonicity_multiple_samples(model, sample, feature, start, stop, ste
     report.graphs.append(fig)
     if monotonic:
         report.metrics["monotonic"] = True
-        report.metrics["monotonic_score"] = 1
+        report.metrics["monotonic_mse"] = 0
     else:
         report.metrics["monotonic"] = False
         monotonic_curve, m_mse_score = monotonicity_mse(predictions)
-        report.metrics["monotonic_score"] = m_mse_score
+        report.metrics["monotonic_mse"] = m_mse_score
         plt.plot(colValues, monotonic_curve, linestyle='dashed', color='red', alpha=0.7, label="Monotonic Approximation")
     report.metrics["monotonic_means_std"] = np.nanstd(predictions)
     plt.plot(colValues, predictions, color='blue', alpha=0.7, label="Predictions Curve")
@@ -218,4 +215,4 @@ def check_monotonicity_multiple_samples(model, sample, feature, start, stop, ste
     plt.xlabel(f'Feature {feature} value')
     plt.ylabel('Predict proba')
     plt.legend(loc="lower right")
-    return report
\ No newline at end of file
+    return report
